// Copyright 2010, 2011, 2012 by Jon Dart. All Rights Reserved.
#include "board.h"
#include "notation.h"
#include "legal.h"
#include "hash.h"
#include "globals.h"
#include "chessio.h"
#include "util.h"
#include "search.h"
#include <iostream>
#include <fstream>
#include <ctype.h>
#include <map>
extern "C" {
#include <math.h>
};

static const int MIN_PLY = 16;

int CDECL main(int argc, char **argv)
{
    Bitboard::init();
    initOptions(argv[0]);
    Attacks::init();
    Scoring::init();
    options.search.hash_table_size = 64*1024*1024;
    if (!initGlobals(argv[0], false)) {
        cleanupGlobals();
        exit(-1);
    }
    atexit(cleanupGlobals);
    delayedInit();
    if (EGTBMenCount) {
        cerr << "Initialized tablebases" << endl;
    }
    options.book.book_enabled = options.log_enabled = 0;

    int arg = 1;
    unsigned minMoves = 30;
    int minELO = 0;
    // time limit in ms.
    int timeLimit = 100;

    if (argc ==1) {
        cerr << "usage: select3 -t <search time> <input file>" << endl;
        return -1;
    }
    else {
        SearchController *searcher = new SearchController();
        Statistics stats;
        for (;arg < argc;arg++) {
            ifstream epd_file( argv[arg], ios::in);
            int c;
            int count = 0;
            hash_t game_hash;
            ColorType side;
            string result, white, black;
            if (!epd_file.good()) {
                cerr << "could not open file " << argv[arg] << endl;
                exit(-1);
            }
            else {
                EPDRecord  rec;
                Board board;
                while (epd_file.good() && !epd_file.eof()) {
                    if (ChessIO::readEPDRecord(epd_file, board, rec)) {
                        string moveStr;
                        if (rec.getVal("bm", moveStr)) {
                            Move m = Notation::value(board,board.sideToMove(),Notation::WB_IN,moveStr);
                            if (!IsNull(m)) {
                                cout << board;
                                cout << " bm ";
                                Notation::image(board,m,Notation::SAN_OUT,cout);
                                cout << ";" << endl;
                            }
                        }
                    }
                }
                epd_file.close();
            }
        }
    }

    return 0;
}
